==> haskell-persistent-sqlite-2.13.1.1-56-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.1
visibility:             public
id:                     persistent-sqlite-2.13.1.1-AkPw7bVU2MHA7qZ9KJ02uq
key:                    persistent-sqlite-2.13.1.1-AkPw7bVU2MHA7qZ9KJ02uq
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    ba61c317eb36c9a393db5a5de170323a
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.1.1
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.1.1 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.1.1 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.1-AkPw7bVU2MHA7qZ9KJ02uq
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
include-dirs:           /usr/include
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    containers-0.6.7 microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    monad-logger-0.3.42-8CskNFmll7427ag5mqbmhY mtl-2.3.1
    persistent-2.14.5.2-GJyCnJ8J8PvBVRSOBxUsv4
    resource-pool-0.2.3.2-3uIbkUYrHNdAfRBpvdjlDL
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.13.1.1-57-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.1
visibility:             public
id:                     persistent-sqlite-2.13.1.1-E48tqF9oldf4Mp9WevHUeT
key:                    persistent-sqlite-2.13.1.1-E48tqF9oldf4Mp9WevHUeT
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    869313475c3c8c82ae94443348401190
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.1.1
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.1.1 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.1.1 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.1-E48tqF9oldf4Mp9WevHUeT
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
include-dirs:           /usr/include
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    containers-0.6.7 microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w mtl-2.3.1
    persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
    resource-pool-0.2.3.2-73AdA0RAXUL5Z2VU9q4gfk
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
